<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'Fòrou de SPIP (privat e pùblicou)',
	'forum_slogan' => 'Gestioun dei fòrou privat e pùblicou en SPIP',
];
